==> haskell-logging-facade-0.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS
key: logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
abi: 1e64a8b9e88abcefd43bb1efb7a913da
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS
depends:
    base-4.10.1.0 call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
    transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=80879ea65722c5998aff02ea5d901642
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-7yWy28NRbT2GPlUzke1DxE
key: logging-facade-0.3.0-7yWy28NRbT2GPlUzke1DxE
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
abi: b8c21e9e91bfba90c7e31efc759f7373
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-7yWy28NRbT2GPlUzke1DxE
depends:
    base-4.10.1.0 call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
    transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=80879ea65722c5998aff02ea5d901642
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
